@@ -39,7 +39,7 @@
 #include "dealerinfo.h"
 #include "patsolve/clocksolver.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
 
 Clock::Clock( const DealerInfo * di )
@@ -162,4 +162,4 @@ public:
 } clockDealerInfo;
 
 
-#include "clock.moc"
+
