@@ -42,8 +42,8 @@
 #include "speeds.h"
 #include "patsolve/freecellsolver.h"
 
-#include <KDebug>
-#include <KLocale>
+#include <QDebug>
+#include <KLocalizedString>
 
 
 const int CHUNKSIZE = 100;
@@ -275,4 +275,4 @@ public:
 } freecellDealerInfo;
 
 
-#include "freecell.moc"
+
