@@ -40,10 +40,10 @@
 #include "kabstractcarddeck.h"
 #include "kcardpile.h"
 
-#include <KDebug>
+#include <QDebug>
 
-#include <QtGui/QGraphicsSceneWheelEvent>
-#include <QtGui/QPainter>
+#include <QGraphicsSceneWheelEvent>
+#include <QPainter>
 
 #include <cmath>
 
@@ -1257,4 +1257,4 @@ void KCardScene::drawForeground ( QPainter * painter, const QRectF & rect )
 }
 
 
-#include "kcardscene.moc"
+
